pub enum VerificationState {
Show 13 variants
Created,
Requested,
NoSupportedMethods,
Ready,
SasConfirm,
QrScan,
QrScanned,
QrConfirm,
Done,
Cancelled,
Dismissed,
RoomLeft,
Error,
}Variants
Created
We created and sent the request.
We must wait for the other user/device to accept it.
Requested
The other user/device sent us a request.
We should ask the user if they want to accept it.
NoSupportedMethods
We support none of the other user’s verification methods.
Ready
The request was accepted.
We should ask the user to choose a method.
SasConfirm
An SAS verification was started.
We should show the emojis and ask the user to confirm that they match.
QrScan
The user wants to scan a QR Code.
QrScanned
The user scanned a QR Code.
QrConfirm
Our QR Code was scanned.
We should ask the user to confirm that the QR Code was scanned successfully.
Done
The verification was successful.
Cancelled
The verification was cancelled.
Dismissed
The verification was automatically dismissed.
Happens when a received request is not accepted by us after 2 minutes.
RoomLeft
The verification was happening in-room but the room was left.
Error
An unexpected error happened.
Implementations
Sourceimpl VerificationState
impl VerificationState
Sourcefn register_enum() -> Type
fn register_enum() -> Type
Registers the enum only once.